# Changelog

## v0.2.0 - 2022-04-21

- Devops: add support for Python 3.10 [[f0bcadc9]](https://github.com/sphuber/biblary/commit/f0bcadc99ffc037acaae97ad83863f66188c108f)
- Devops: add a continuous deployment workflow [[f1d1e94b]](https://github.com/sphuber/biblary/commit/f1d1e94bacb8f0867985d38aca165955910aa451)

## v0.1.0 - 2022-04-21

First release.
